@@ -1,4 +1,4 @@
-namespace GalagoTests
+namespace Galago.Tests
 {
 	using System;
 	using Galago;
